@@ -167,7 +167,9 @@ sync_clients_mrest = """
         clp1.recarrec recarrec_destinatari,
         ct1.empleat_id empleat_id_destinatari,
         v1t.nom_llarg empleat_nom_destinatari,
-        vt.nom_llarg empleat_nom_destinatari
+        v1e.data_baixa,
+        vt.nom_llarg empleat_nom_client,
+        ve.data_baixa
 
         from clients cl
         join clients_parametres clp on cl.id = clp.client_id
